local harbour = ...

HarbourPrefix = "HARBOUR_V2"

local myMonument = {
    Id = HarbourPrefix .. "_VH"
}

if (foundation.getGameVersion == nil or version.cmp(foundation.getGameVersion(), "1.6") < 0) then
    harbour:log("Hello World: game version anterior to 1.6")
    myMonument.DataType = "MONUMENT"
    _LightTowerBuildingZone = { Polygon = polygon.createCircle( 3.3, { 0, 0 }, 16 ) } 
    _DockBuildingZone = { Polygon = polygon.createRectangle( {16, 4} ) } 
    _PontonBuildingZone = { Polygon = polygon.createRectangle( {4, 4} ) } 
    _RampBuildingZone = { Polygon = polygon.createRectangle( {4, 4} ) } 
else
    harbour:log("Hello World: game version " .. foundation.getGameVersion())
    myMonument.DataType = "BUILDING"

    -- Apply building asset processor
    harbour:registerAssetProcessor("models/core.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
    })

    harbour:registerAssetId("models/core.fbx/Prefab/CoreBuildingPart", HarbourPrefix .. "_CORE_BUILDING_PREFAB")

    -- Register the harbour Core part
    harbour:register({
	DataType = "BUILDING_PART",
	Id = HarbourPrefix .. "_CORE_BUILDING_PART",
	Name = HarbourPrefix .. "_CORE_BUILDING_NAME",
	Description = HarbourPrefix .. "_CORE_BUILDING_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = HarbourPrefix .. "_CORE_BUILDING_PREFAB"
	},
        IsVisibleWhenBuilt = false
    })

    myMonument.AssetCoreBuildingPart = HarbourPrefix .. "_CORE_BUILDING_PART"

    _LightTowerBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createCircle( 3.3, { 0, 0 }, 16 ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
    }}
    _DockBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {16.5, 4.5} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( {16.5, 4.5} ),
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _PontonBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {4.5, 4.5} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( {4.5, 4.5} ),
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _RampBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {4, 4} ),
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    harbour:registerEnumValue ("BUILDING_PART_TYPE", "EXTENSION")
    harbour:registerEnumValue ("BUILDING_PART_TYPE", "DECORATION")
end

-- Register all harbour building parts and their properties
harbour:dofile("scripts/behavior_tree.lua")
harbour:dofile("scripts/job.lua")
--harbour:dofile("scripts/compBoatFlag.lua") -- for future usage
harbour:dofile("scripts/compStaticBoat.lua")
harbour:dofile("scripts/compWaterline.lua")
harbour:dofile("scripts/boat_parts.lua")
--harbour:dofile("scripts/flag_parts.lua") -- for future usage
harbour:dofile("scripts/decoration.lua") -- kept for compatibility

-- Register the harbour monument
myMonument.Name = HarbourPrefix .. "_MONUMENT_NAME"
myMonument.Description = HarbourPrefix .. "_MONUMENT_DESC"
myMonument.BuildingType = "MONUMENT"
myMonument.BuildingPartSetList = {
		{
			Name = HarbourPrefix .. "_TERRAIN_NAME",
	                BuildingPartList = {
		            HarbourPrefix .. "_LIGHT_TOWER_ROOT_PART",
		            HarbourPrefix .. "_LIGHT_ROOF_A_PART",
 		            HarbourPrefix .. "_ENTRANCE_DOOR_A_PART", -- not refactored yet
  		            HarbourPrefix .. "_ENTRANCE_DOOR_B_PART", -- not refactored yet
-- 		            "STONE_GATE_V5_DECORATION_ENTRANCE_DOOR_A_PART", -- not refactored yet
--  		            "STONE_GATE_V5_DECORATION_ENTRANCE_DOOR_B_PART", -- not refactored yet
		            "STONE_GATE_V5_DECORATION_SFENETRE_PART",
		            "STONE_GATE_V5_DECORATION_LFENETRE_PART",
		            "STONE_GATE_V5_DECORATION_PFENETRE_PART",
		            "STONE_GATE_V5_DECORATION_ARROWSLIT_PART",
		            HarbourPrefix .. "_PONTOON_PART",
		            HarbourPrefix .. "_RAMP_PART",
		            HarbourPrefix .. "_DOOR_PART"
                        }
                },
                {
			Name = HarbourPrefix .. "_WATER_NAME",
	                BuildingPartList = {
		            HarbourPrefix .. "_BOAT_STATIC_PART",
		            HarbourPrefix .. "_BOAT_PART"
--[[, -- for future usage
                            HarbourPrefix .. "_FLAG_RED_ROOT_PART",
                            HarbourPrefix .. "_FLAG_BLUE_ROOT_PART"
]]
                        }
                }
}
myMonument.IsManuallyUnlocked = false
myMonument.IsDestructible = true
myMonument.IsEditable = true
myMonument.IsClearTrees = true

-- Register the Harbour monument
harbour:register(myMonument)
